@@ -16,6 +16,7 @@
 #    under the License.
 
 MIDONET_USE_CASSANDRA=$1
+PYTHON_PREFIX=$2
 
 # Remove possible reminders from the previous devmido runs
 rm -rf \
@@ -42,5 +43,4 @@ apt-get install -y --no-install-recommends --no-install-suggests \
     ${CASSANDRA_PKG} \
     midonet-tools \
     midonet-cluster \
-    midolman \
-    python-midonetclient
+    midolman
