@@ -12,6 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import datetime
+
+from alembic import op
+import sqlalchemy as sa
+
+
 """add data sync
 
 Revision ID: d8a5c672761
@@ -24,10 +30,6 @@ Create Date: 2015-03-16 06:04:40.695379
 revision = 'd8a5c672761'
 down_revision = '25aeae45d4ad'
 
-from alembic import op
-import datetime
-import sqlalchemy as sa
-
 
 def upgrade():
 
@@ -53,6 +55,7 @@ def upgrade():
                         ['active_version'],
                         ['midonet_data_versions.id']))
 
-    op.execute("INSERT INTO midonet_data_state (id, last_processed_task_id, "
-               "updated_at, active_version, readonly) VALUES (1, NULL, '%s', "
-               "NULL, false)" % (datetime.datetime.utcnow()))
+    op.execute(  # nosec
+        "INSERT INTO midonet_data_state (id, last_processed_task_id, "
+        "updated_at, active_version, readonly) VALUES (1, NULL, '%s', "
+        "NULL, false)" % (datetime.datetime.utcnow()))
